if_pass contains item facility values for test items for students who
passed the test
if_fail contains item facility values for test items for students who did not pass the test
if_total contains item facility values for test items
b_index contains b-index values for items on the test
agree_stat contains agreement statistic values for items on the test
item_phi contains item phi values for items on the test